package nl.iobyte.themepark.api.attraction;

import nl.iobyte.themepark.api.events.region.ChangeDataEvent;
import nl.iobyte.themepark.api.events.region.ChangeLoreEvent;
import nl.iobyte.themepark.api.events.region.ChangeMaterialEvent;
import nl.iobyte.themepark.api.events.region.ChangeNameEvent;
import org.bukkit.Bukkit;
import org.bukkit.Material;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;

public class Region {

    private String id, name;
    private Material material;
    private short data;
    private List<String> lore;
    private LinkedHashMap<String, Attraction> attractions = new LinkedHashMap<>();

    public Region(String id, String name, List<String> lore) {
        this.id = id;
        this.name = name;
        this.material = Material.NAME_TAG;
        this.data = 0;
        this.lore = lore;
    }

    public Region(String id, String name, List<String> lore, Material material, short data) {
        this.id = id;
        this.name = name;
        this.material = material;
        this.data = data;
        this.lore = lore;
    }

    public String getId() {
        return id;
    }

    public String getName() {
        return name;
    }

    public void setName(String string) {
        if(string == null || string.equals(""))
            return;

        if(string.equals(name))
            return;

        String old = name;
        name = string;
        ChangeNameEvent e = new ChangeNameEvent(this, old, string);
        Bukkit.getPluginManager().callEvent(e);
    }

    public Material getMaterial() {
        return material;
    }

    public void setMaterial(Material material) {
        if(material == null || material == this.material)
            return;

        Material old = this.material;
        this.material = material;
        ChangeMaterialEvent e = new ChangeMaterialEvent(this, old, material);
        Bukkit.getPluginManager().callEvent(e);
    }

    public short getData() {
        return data;
    }

    public void setData(short data) {
        if(this.data == data)
            return;

        short old = this.data;
        this.data = data;
        ChangeDataEvent e = new ChangeDataEvent(this, old, data);
        Bukkit.getPluginManager().callEvent(e);
    }

    public List<String> getLore() {
        return lore;
    }

    public void setLore(List<String> lore) {
        if(this.lore.equals(lore))
            return;

        List<String> old = this.lore;
        this.lore = lore;

        ChangeLoreEvent e = new ChangeLoreEvent(this, old, lore);
        Bukkit.getPluginManager().callEvent(e);
    }

    public void setLore(int i, String string) {
        if(lore.size() >= 4 || i >= 4)
            return;

        List<String> old = lore;
        lore = new ArrayList<>();
        lore.addAll(old);

        if(!string.equals("NULL")) {
            if (lore.size() >= i)
                for (int a = 0; a <= (i - lore.size()); a++)
                    lore.add(" ");

            lore.set(i, string);
        } else {
            lore.remove(i);
        }

        ChangeLoreEvent e = new ChangeLoreEvent(this, old, lore);
        Bukkit.getPluginManager().callEvent(e);
    }

    public LinkedHashMap<String, Attraction> getAttractions() {
        return attractions;
    }

    public void setAttractions(LinkedHashMap<String, Attraction> attractions) {
        this.attractions = attractions;
    }

    public void addAttraction(Attraction attraction) {
        if(attraction == null)
            return;

        if(!isAttraction(attraction))
            attractions.put(attraction.getId(), attraction);
    }

    public boolean isAttraction(Attraction attraction) {
        if(attraction == null)
            return false;

        return attractions.containsKey(attraction.getId());
    }

    public void removeAttraction(Attraction attraction) {
        if(isAttraction(attraction))
            attractions.remove(attraction.getId());
    }

}
