package nl.iobyte.themepark.command;

import nl.iobyte.menuapi.map.WeakConcurrentHashMap;
import nl.iobyte.themepark.api.API;
import nl.iobyte.themepark.api.attraction.Attraction;
import nl.iobyte.themepark.ridecount.RideCountAPI;
import nl.iobyte.themepark.util.Color;
import nl.iobyte.themepark.util.MessageUtil;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import java.util.Scanner;

public class RidecountCommand implements CommandExecutor {

    private static WeakConcurrentHashMap<String, String> data = new WeakConcurrentHashMap<>(5 * 60 * 1000);

    @Override
    public boolean onCommand(CommandSender sender, Command cmd, String label, String[] args) {
        if(!cmd.getName().equalsIgnoreCase("ridecount"))
            return false;

        if(args.length == 0 || args[0].equalsIgnoreCase("help")) {
            sender.sendMessage(Color.color("&f&L>==== &r&6Ridecount &L&f ====<"));
            sender.sendMessage(Color.color("&f/ridecount help"));
            sender.sendMessage(Color.color("&f/ridecount get <player> <id>"));
            sender.sendMessage(Color.color("&f/ridecount add <player> <id> <amount>"));
            return true;
        }

        if(args[0].equalsIgnoreCase("get")) {
            if(args.length < 3) {
                sender.sendMessage(Color.color(MessageUtil.getMessage("prefix")+" &4/ridecount get <player> <id>"));
                return true;
            }

            if(!API.isAttraction(args[2])) {
                String message = MessageUtil.getMessage("attraction.not");
                message = message.replace("{id}", args[2]);
                sender.sendMessage(Color.color(message));
                return true;
            }

            Attraction attraction = API.getAttraction(args[2]);
            RideCountAPI.getCount(args[1], attraction).thenAccept(points -> {
                if(points < 0) {
                    sender.sendMessage(Color.color(MessageUtil.getMessage("noplayer").replace("{name}", args[1])));
                    return;
                }

                String mesage = MessageUtil.getMessage("ridecount.count");
                mesage = mesage.replace("{name}", attraction.getName());
                mesage = mesage.replace("{count}", points.toString());
                sender.sendMessage(Color.color(mesage));
            });
            return true;
        }

        if(args[0].equalsIgnoreCase("add")) {
            if(args.length < 4) {
                sender.sendMessage(Color.color(MessageUtil.getMessage("prefix")+" &4/ridecount add <player> <id> <amount>"));
                return true;
            }

            if(!API.isAttraction(args[2])) {
                String message = MessageUtil.getMessage("attraction.not");
                message = message.replace("{id}", args[2]);
                sender.sendMessage(Color.color(message));
                return true;
            }

            if(!isInteger(args[3])) {
                sender.sendMessage(Color.color(MessageUtil.getMessage("nonumber").replace("{number}", args[3])));
                return true;
            }

            int amount = Integer.parseInt(args[3]);
            Attraction attraction = API.getAttraction(args[2]);
            RideCountAPI.addCount(args[1], attraction, amount).thenAccept(result -> {
                if(!result) {
                    sender.sendMessage(Color.color(MessageUtil.getMessage("noplayer").replace("{name}", args[1])));
                    return;
                }

                String mesage = MessageUtil.getMessage("ridecount.add");
                mesage = mesage.replace("{name}", API.getAttraction(args[2]).getName());
                mesage = mesage.replace("{count}", Integer.toString(amount));
                sender.sendMessage(Color.color(mesage));
            });
            return true;
        }

        return false;
    }



    private boolean isInteger(String s) {
        int radix = 10;
        Scanner sc = new Scanner(s.trim());
        if(!sc.hasNextInt(radix)) return false;
        sc.nextInt(radix);
        return !sc.hasNext();
    }

}

