package nl.iobyte.themepark.database;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.HashMap;
import java.util.Map;

public abstract class DB {

    public abstract Connection getConnection();

    public abstract void closeConnection();

    public boolean execute(String query, HashMap<Integer, Object> objects) {
        if(query == null || query.isEmpty())
            return false;

        if(getConnection() == null)
            return false;

        try {
            PreparedStatement statement = getConnection().prepareStatement(query);
            statement.closeOnCompletion();
            if(objects != null)
                for(Map.Entry<Integer, Object> entry : objects.entrySet())
                    statement.setObject(entry.getKey(), entry.getValue());

            return statement.execute();
        } catch(Exception e) {
            e.printStackTrace();
            return false;
        }
    }

    public int executeUpdate(String query, HashMap<Integer, Object> objects) {
        if (query == null || query.isEmpty())
            return 0;

        if(getConnection() == null)
            return 0;

        try {
            PreparedStatement statement = getConnection().prepareStatement(query);
            statement.closeOnCompletion();
            for (Map.Entry<Integer, Object> entry : objects.entrySet())
                statement.setObject(entry.getKey(), entry.getValue());

            return statement.executeUpdate();
        } catch (Exception e) {
            e.printStackTrace();
            return 0;
        }
    }

    public ResultSet executeQuery(String query, HashMap<Integer, Object> objects) {
        if (query == null || query.isEmpty())
            return null;

        if (getConnection() == null)
            return null;

        try {
            PreparedStatement statement = getConnection().prepareStatement(query);
            statement.closeOnCompletion();
            if (objects != null)
                for (Map.Entry<Integer, Object> entry : objects.entrySet())
                    statement.setObject(entry.getKey(), entry.getValue());

            return statement.executeQuery();
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

}
