package nl.iobyte.themepark.database;

import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;
import nl.iobyte.themepark.ThemeParkPlugin;
import java.io.File;
import java.io.IOException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.Properties;

public class SQLite extends DB {

    private String dbName;
    private HikariDataSource source;
    private Connection con;

    /**
     * Initialize a new connection
     *
     * @param dbName The database name
     */
    public SQLite(String dbName) {
        this.dbName = dbName;

        File dbFile = new File(ThemeParkPlugin.getInstance().getDataFolder(), dbName + ".db");
        if (!dbFile.exists()) {
            try {
                System.out.println("Generating the " + dbName + ".db!");
                if (!dbFile.createNewFile()) {
                    System.out.println("Couldn't generate the " + dbName + ".db!");
                    return;
                }
            } catch (IOException e) {
                System.out.println("Couldn't generate the " + dbName + ".db!");
                return;
            }
        }

        HikariConfig config = new HikariConfig();
        config.setPoolName(ThemeParkPlugin.getInstance().getName());
        config.setUsername(null);
        config.setPassword(null);
        config.setDriverClassName("org.sqlite.JDBC");
        config.setConnectionTestQuery("SELECT 1");
        config.setMaximumPoolSize(1);

        Properties prop = new Properties();
        prop.setProperty("date_string_format", "yyyy-MM-dd HH:mm:ss");

        config.setJdbcUrl("jdbc:sqlite:" + dbFile.getAbsolutePath());
        config.setDataSourceProperties(prop);
        source = new HikariDataSource(config);

        try {
            con = source.getConnection();
        } catch (SQLException e) {
            e.printStackTrace();
        }
    }

    /**
     * Get connection
     * @return Connection Instance
     */
    public Connection getConnection() {
        return con;
    }

    /**
     * Close connection
     */
    public void closeConnection() {
        System.out.println("Closing the database connection for " + dbName + ".db!");
        try {
            con.close();
        } catch (SQLException e) {
            e.printStackTrace();
        }

        source.close();
    }

}